/*
    This file is part of KitchenSync.

    Copyright (c) 2005 Cornelius Schumacher <schumacher@kde.org>
    Copyright (c) 2010 Tejas Guruswamy <masterpatricko@gmail.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
    USA.
*/

#include "configguiakonadi.h"

#include <klocale.h>
#include <kdialog.h>
#include <akonadi/collectionrequester.h>
#include <akonadi/collectionfetchjob.h>

#include <QtGui/QLayout>
#include <QtXml/QtXml>
#include <QtGui/QLabel>

ConfigGuiAkonadi::ConfigGuiAkonadi( const QSync::Member &member, QWidget *parent )
  : ConfigGui( member, parent )
{
  QHBoxLayout* clayout = new QHBoxLayout(this);
  QLabel* contacts = new QLabel("Default contacts collection", this);
  clayout->addWidget(contacts);
  mContacts = new Akonadi::CollectionRequester(this);
  mContacts->setMimeTypeFilter(QStringList() << "text/directory");
  clayout->addWidget(mContacts);
  topLayout()->addLayout(clayout);
  
  QHBoxLayout* elayout = new QHBoxLayout(this);
  QLabel* events = new QLabel("Default events collection", this);
  elayout->addWidget(events);
  mEvents = new Akonadi::CollectionRequester(this);
  mEvents->setMimeTypeFilter(QStringList() << "text/calendar" 
                                           << "application/x-vnd.akonadi.calendar.event" 
                                           << "application/x-vnd.akonadi.calendar.todo");
  elayout->addWidget(mEvents);
  topLayout()->addLayout(elayout);

  topLayout()->addStretch( 1 );
}

void ConfigGuiAkonadi::load( const QString &xml )
{
  QDomDocument doc;
  doc.setContent( xml );
  QDomElement docElement = doc.documentElement();
  QDomNode n;
  for ( n = docElement.firstChild(); !n.isNull(); n = n.nextSibling() ) {
    QDomElement e = n.toElement();
    if ( e.tagName() == "contacts" ) {
        Akonadi::Collection col = getCollection( e.text().toLongLong() );
        if (col.isValid())
            mContacts->setCollection(col);
    } else if ( e.tagName() == "events" ) {
        Akonadi::Collection col = getCollection( e.text().toLongLong() );
        if (col.isValid())
            mEvents->setCollection(col);
    }
  }   
}

QString ConfigGuiAkonadi::save()
{
  QString xml;
  xml = "<config>";
  xml += "<contacts>" + (mContacts->collection().isValid() ? QString::number( mContacts->collection().id() ) : QString()) + "</contacts>";
  xml += "<events>" + (mContacts->collection().isValid() ? QString::number( mEvents->collection().id() ) : QString()) + "</events>";
  xml += "</config>";

  return xml;
}

Akonadi::Collection ConfigGuiAkonadi::getCollection(qint64 id)
{
    //FIXME: Not returning a collection if specifying only the wanted collection!
    Akonadi::CollectionFetchJob *job = new Akonadi::CollectionFetchJob( Akonadi::Collection::root(), 
                                                                        Akonadi::CollectionFetchJob::Recursive );
    
    if ( !job->exec() )
        return Akonadi::Collection();
    
    Akonadi::Collection::List cols = job->collections();
    
    if ( cols.isEmpty() )
        return Akonadi::Collection();
    
    Akonadi::Collection col;
    foreach ( Akonadi::Collection const &c, cols ) {
        if ( c.id() == id )
            col = c;
    }
    return col;
}