/*
    This file is part of KitchenSync.

    Copyright (c) 2005 Cornelius Schumacher <schumacher@kde.org>
    Copyright (c) 2010 Tejas Guruswamy <masterpatricko@gmail.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
    USA.
*/

#include "configguikdepim.h"

#include <klocale.h>
#include <kdialog.h>

#include <QtGui/QLayout>
#include <QtGui/QCheckBox>
#include <QtXml/QtXml>

ConfigGuiKdepim::ConfigGuiKdepim( const QSync::Member &member, QWidget *parent )
  : ConfigGui( member, parent )
{
  mIgnoreContacts = new QCheckBox( i18n("Sync even if Akonadi has Contact resources"), this );
  topLayout()->addWidget( mIgnoreContacts );
  
  mIgnoreEvents = new QCheckBox( i18n("Sync even if Akonadi has Event resources"), this );
  topLayout()->addWidget( mIgnoreEvents );

  topLayout()->addStretch( 1 );
}

void ConfigGuiKdepim::load( const QString &xml )
{
  QDomDocument doc;
  doc.setContent( xml );
  QDomElement docElement = doc.documentElement();
  QDomNode n;
  for ( n = docElement.firstChild(); !n.isNull(); n = n.nextSibling() ) {
    QDomElement e = n.toElement();
    if ( e.tagName() == "ignore_akonadi_contacts" ) {
        mIgnoreContacts->setChecked( e.text() == "true" );
    } else if ( e.tagName() == "ignore_akonadi_events" ) {
        mIgnoreEvents->setChecked( e.text() == "true" );
    }
  }
}

QString ConfigGuiKdepim::save()
{
  QString xml;
  xml = "<config>";
  xml += "<ignore_akonadi_contacts>";
  if ( mIgnoreContacts->isChecked() ) {
      xml += "true";
  } else {
      xml += "false";
  }
  xml += "</ignore_akonadi_contacts>";
  xml += "<ignore_akonadi_events>";
  if ( mIgnoreEvents->isChecked() ) {
    xml += "true";
  } else {
    xml += "false";
  }
  xml += "</ignore_akonadi_events>";
  xml += "</config>";

  return xml;
}
